# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.unchecked_base_model import UncheckedBaseModel


class Link(UncheckedBaseModel):
    end_index: int = pydantic.Field()
    """
    End index of link text
    """

    start_index: int = pydantic.Field()
    """
    Start index of link text
    """

    text: str = pydantic.Field()
    """
    Link text
    """

    url: str = pydantic.Field()
    """
    Link URL
    """

    model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)
